@@ -242,12 +242,12 @@ function positionInterfaces() {
   
   if (NFC_OFF == "" && INSERT_OFF == "" && SWIPE_OFF != "") {
     getID = getControlByName("Swipe");
-    getID[0].style.left = "330px";
+    getID[0].style.left = "102px";
   }
   
   if (NFC_OFF == "" && INSERT_OFF != "" && SWIPE_OFF == "") {
     getID = getControlByName("Insert");
-    getID[0].style.left = "350px";
+    getID[0].style.left = "102px";
   }
 }
 //--XXXXboundary action script
@@ -405,21 +405,21 @@ function showCardBrands( cardBrands )
 {
     // For Display DisplayCards
     var XCardData = 
-    [{NAME:"AMEX",       NameID:"Img1",  WIDTH:56}, // get these from AB elements
-     {NAME:"APPLEPAY",   NameID:"Img2",  WIDTH:86},
-     {NAME:"DISCOVER",   NameID:"Img3",  WIDTH:90},
-     {NAME:"GOOGLEPAY",  NameID:"Img4",  WIDTH:85},
-     {NAME:"INTERAC",    NameID:"Img5",  WIDTH:55},
-     {NAME:"JCB",        NameID:"Img6",  WIDTH:75},
-     {NAME:"MASTERCARD", NameID:"Img7",  WIDTH:90},
-     {NAME:"SAMSUNGPAY", NameID:"Img8",  WIDTH:55},
-     {NAME:"UNIONPAY",   NameID:"Img9",  WIDTH:82},
-     {NAME:"VISA",       NameID:"Img10",  WIDTH:87}
+    [{NAME:"AMEX",       NameID:"Img1",  WIDTH:22}, // get these from AB elements
+     {NAME:"APPLEPAY",   NameID:"Img2",  WIDTH:34},
+     {NAME:"DISCOVER",   NameID:"Img3",  WIDTH:36},
+     {NAME:"GOOGLEPAY",  NameID:"Img4",  WIDTH:34},
+     {NAME:"INTERAC",    NameID:"Img5",  WIDTH:22},
+     {NAME:"JCB",        NameID:"Img6",  WIDTH:30},
+     {NAME:"MASTERCARD", NameID:"Img7",  WIDTH:36},
+     {NAME:"SAMSUNGPAY", NameID:"Img8",  WIDTH:22},
+     {NAME:"UNIONPAY",   NameID:"Img9",  WIDTH:33},
+     {NAME:"VISA",       NameID:"Img10",  WIDTH:35}
     ];
     
     var XMaxCardCount = 10;
-    var XDisplayTopStr = "350px";
-    var XScreenWidth = 800;
+    var XDisplayTopStr = "185px";
+    var XScreenWidth = 320;
     
     var XDisplayCount = 0;
     var XDisplayNames = [];
@@ -600,6 +600,65 @@ function updatePresentCardMessage( message, cardInterfaceVariableName, cardBrand
     }
 }
 //--XXXXboundary action script
+function positionStatusBarIcons() {
+  var lteSignal = variableGet("network.lte.signal");
+  var wifiSignal = variableGet("network.wifi.net.signal")
+  var ltePresence = variableGet("network.lte.presence");
+  var bleStatus = variableGet("pinpad.bleStatus");
+  
+  var wifiSignalIconID = getControlByName("wifiSignalIcon");
+  var lteSignalIconID = getControlByName("lteSignalIcon");
+  var lteOperatorID = getControlByName("lteOperator");
+  var bleIconID = getControlByName("bleStatus");
+  
+  var currentIconLeft = 3;
+  
+  if( ( lteSignal !== null ) && ( lteSignal !== "" ) )
+  {
+      lteSignalIconID[ 0 ].style.left = currentIconLeft + "px";
+      // icon width hardcoded
+      currentIconLeft += 20;
+  }
+  
+  if( ltePresence == "1" )
+  {
+      currentIconLeft += 1; // add 1 pixel padding on both sides of text
+      lteOperatorID[ 0 ].style.left = currentIconLeft + "px";
+      currentIconLeft += lteOperatorID[ 0 ].offsetWidth + 1;
+  }
+  
+  if( ( wifiSignal !== null ) && ( wifiSignal !== "" ) )
+  {
+      wifiSignalIconID[ 0 ].style.left = currentIconLeft + "px";
+      // icon width hardcoded
+      currentIconLeft += 20;
+  }
+  
+  if( ( bleStatus !== null ) && ( bleStatus !== "" ) )
+  {
+      bleIconID[ 0 ].style.left = currentIconLeft + "px";
+  }
+}
+//--XXXXboundary action script
+function TranslateBLEStatus()
+{
+    var statusVarName = "pinpad.bleStatus";
+    var bleStatus = variableGet( "network.ble.status" );
+    
+    if( bleStatus == "idle" )
+    {
+        variableSet( statusVarName, "1" );
+    }
+    else if( bleStatus == "connected" )
+    {
+        variableSet( statusVarName, "2" );
+    }
+    else
+    {
+        variableSet( statusVarName, "3" );
+    }
+}
+//--XXXXboundary action script
 function registerForCVVError()
 {
     registerForEvent( "onReturn", "manualCVV2", function ( name, obj, response ) {
@@ -678,7 +737,7 @@ function initSelectInstallmentPlan()
 
     const maxPlanNum = 2;
 
-    const maxPlans = function()
+    const planNum = function()
     {
         return ( plans.length > maxPlanNum ) ? maxPlanNum : plans.length;
     }();
@@ -700,8 +759,13 @@ function initSelectInstallmentPlan()
         variableSet( "set2", "1" );
     }
     
-    for ( var i = 1; i <= maxPlans; i++ )
+    for ( i = 1; i <= planNum; i++ )
     {
+        if ( plans.length < i )
+        {
+            break;
+        }
+        
         const plan = plans[ i - 1 ];
         
         const frequencyAbbreviation = function()
@@ -736,7 +800,6 @@ function initSelectInstallmentPlan()
         
         variableSet( "terms" + i, plan.Terms );
     }
-
 }
 //--XXXXboundary action script
 function confirmPlan( n )
@@ -890,3 +953,81 @@ function endInstallmentPlanSelection( button )
     fireEvent( event );
 }
 //--XXXXboundary action script
+function SendCustomEvent( name, value )
+{
+    eventData = '{"' + name + '": "' + value + '"}';
+    eventJSON = '{ "Action": "event", "CustomEventData": ' + eventData + '}';
+    fireEvent( eventJSON );
+}
+//--XXXXboundary action script
+function SendCustomEventGroup( eventDataJSON )
+{
+    // eventData should contain correctly formatted JSON object
+    eventJSON = '{ "Action": "event", "CustomEventData": ' + JSON.stringify( eventDataJSON ) + '}';
+    fireEvent( eventJSON );
+}
+//--XXXXboundary action script
+function showMSRMessageOrError( msrData, msrError ) {
+    function hasAnyTracks( data ) {
+        for ( var trackId = 1; trackId <= 3; trackId++ ) {
+            if ( data[ 'track' + trackId ] || data[ 'track' + trackId + "Encrypted" ] || data[ 'track' + trackId + "Masked" ] ) {
+                return true;
+            }
+        }
+        return false;
+    }
+
+    function getPromptToDisplay( msrData, msrError ) {
+        if ( msrData ) {
+            if ( hasAnyTracks( msrData ) ) {
+                return "MSR_Processing";
+            } else {
+                return "MSR_CardError";
+            }
+        } else if ( msrError ) {
+            if ( msrError.errorCode != eqErrors.MSR_TRACK_NOT_FOUND.errorCode ) {
+                return null; // Not an MSR error
+            }
+            return "MSR_CardError";        
+        } else {
+            return null; //
+        }
+    }
+
+    function getPromptValue( promptName ) {
+        if ( !promptName ) {
+            return null;
+        }
+        var promptValue = null;
+        var langCode = variableGet( "LanguageCode" );
+        if ( langCode ) {
+            promptValue = getCurrentAppPrompt( promptName, langCode );
+        }
+        if ( !promptValue ) {
+            promptValue = getCurrentAppDefaultLangPrompt( promptName );
+        }
+        return promptValue;
+    }
+
+    var promptValue = getPromptValue( getPromptToDisplay( msrData, msrError ) );
+    if ( !promptValue ) {
+        return;
+    }
+
+    // Hide SCR, NFC< MSR icons
+    variableSet( "InterfaceSCR", "" );
+    variableSet( "InterfaceNFC", "" );
+    variableSet( "InterfaceMSR", "" );
+
+    // Set MSR prompt
+    variableSet( "pinpad.MSRMessage", promptValue );
+
+    // Show MSR prompt
+    var elem = document.getElementsByClassName( "TxtMSRMessage" );
+    for ( var i = 0; i < elem.length; i++ ) {
+        elem[ i ].classList.remove( "hidden" );
+    }
+
+    stopTimer( "Timeout" );
+}
+//--XXXXboundary action script
