@@ -148,7 +148,13 @@
         getWifiHeartBeat: function () {
             return wifiImpl.getWifiHeartBeat();
         },
+        forgetNetwork: function () {
+            wifiImpl.forgetNetwork();
+        },
 
+        getConfiguredSSID: function () {
+            return wifiImpl.getConfiguredSSID();
+        },
         /**
             {
                 ssid: "",
@@ -179,8 +185,13 @@
 
         setWifiHeartBeat: function (args) {
             wifiImpl.setWifiHeartBeat(args);
+        },
+        getBlackListCleanup: function () {
+            return wifiImpl.getBlackListCleanup();
+        },
+        setBlackListCleanup: function (args) {
+            return wifiImpl.setBlackListCleanup(args);
         }
-
     };
 
     // bleImpl
@@ -362,7 +373,7 @@
                 }
             });
             registry.subscribe(conStr + "*");
-        }
+        };
     })();
 
     // networkImpl
@@ -419,27 +430,39 @@
         };
 
         networkImpl.verifyConnection = function (args) {
-            var interfaces = args.iface !== "usb" ? ["eth0", "eth1", "wlan0"] : ["usb0"];
+            var iface = null;
+            switch (args.iface) {
+            case "usb":
+                iface = "usb0";
+                break;
+            case "wlan":
+                iface = "wlan0";
+                break;
+            default:
+                iface = registry.getValue("network.tcp.eth1.mac") ? "eth1" : "eth0";
+                break;
+            }
 
-            for (var i = 0; i < interfaces.length; i++) {
-                if (interfaces[i] !== "wlan0") {
-                    // check for error
-                    var err = registry.getValue("network." + interfaces[i] + ".status");
-                    if (err) {
-                        args.fail(err);
-                        return;
-                    }
-                }
-
-                // check connection status
-                var isRunning = registry.getValue("network." + interfaces[i] + ".tcp.running");
-                if (isRunning === "0") {
-                    args.fail("disconnected");
+            var ipAddr = null;
+            if (iface !== "wlan0") {
+                // check for error
+                var err = registry.getValue("network." + iface + ".status");
+                if (err) {
+                    args.fail(err);
                     return;
                 }
             }
 
-            args.success();
+            // check connection status
+            var isRunning = registry.getValue("network." + iface + ".tcp.running");
+            if (isRunning === "0") {
+                args.fail("disconnected");
+                return;
+            }
+            ipAddr = ipAddr || registry.getValue("network." + iface + ".tcp.ip");
+
+            ipAddr = ipAddr || "Not set";
+            args.success(iface, ipAddr);
         };
 
         networkImpl.enableDHCP = function (args) {
@@ -539,7 +562,6 @@
         wifiImpl.getNetworkInterfaces = function (callback) {
             var xhttp = new XMLHttpRequest();
             xhttp.onreadystatechange = function () {
-                var success = false;
                 try {
                     if (this.readyState != 4 || this.status != 200) {
                         return;
@@ -569,12 +591,35 @@
             registry.setValue("%network.wifi.net.0.heartbeat", args);
         };
 
+        wifiImpl.getBlackListCleanup = function () {
+            return registry.getValue("%network.wifi.net.0.blacklist_cleanup");
+        };
+        wifiImpl.setBlackListCleanup = function (args) {
+            registry.setValue("%network.wifi.net.0.blacklist_cleanup", args);
+        };
+
+        wifiImpl.forgetNetwork = function () {
+            registry.deleteKey('%network.wifi.net.0.*');
+        };
+
+        wifiImpl.getConfiguredSSID = function () {
+            return registry.getValue('%network.wifi.net.0.ssid');
+        };
+
         wifiImpl.setWifiConfig = function (wificonfig) {
             var res;
             var heartbeat = registry.getValue("%network.wifi.net.0.heartbeat");
-            res = registry.deleteKey('%network.wifi.net.0.*') === false;
+            var blacklistcleanup = registry.getValue("%network.wifi.net.0.blacklist_cleanup");
+            res = registry.deleteKey('%network.wifi.net.0.bgscan') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.heartbeat') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.blacklist_cleanup') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.ssid') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.tcp.*') === false;
+
             res |= registry.setValue('%network.wifi.net.0.ssid', wificonfig.ssid) === false;
-            res |= registry.setValue('%network.wifi.net.0.psk', wificonfig.psk) === false;
+            if (wificonfig.psk != null) {
+                res |= registry.setValue('%network.wifi.net.0.psk', wificonfig.psk) === false;
+            }
             res |= registry.setValue('%network.wifi.net.0.tcp.dhcp', wificonfig.dhcp) === false;
 
             if (wificonfig.dhcp === 0) {
@@ -587,6 +632,8 @@
 
             res |= registry.setValue('%network.wifi.net.0.bgscan', 'learn:10:-72:600:/tmp/bgscan.log');
             res |= registry.setValue('%network.wifi.net.0.heartbeat', heartbeat);
+            res |= registry.setValue('%network.wifi.net.0.blacklist_cleanup', blacklistcleanup);
+
             return res;
         };
 
@@ -662,12 +709,22 @@
 
                 var ssid = registry.getValue('network.wifi.bss.' + n + '.ssid');
                 if (ssid && ssid.trim()) {
-                    networks.push(ssid);
+                    var pci = registry.getValue('network.wifi.bss.' + n + '.pci');
+                    networks.push({
+                        ssid: ssid,
+                        pciCompatible: ("1" === pci)
+                    });
                 }
                 n++;
             }
-            wifiImpl.callback(networks.sort().filter(function (e, i, a) {
-                return i === a.indexOf(e);
+
+            var compare = function (a, b) {
+                if (a.ssid > b.ssid) { return 1; }
+                if (a.ssid < b.ssid) { return -1; }
+                return 0;
+            };
+            wifiImpl.callback(networks.sort(compare).filter(function (e, i, a) {
+                return i === a.map(function (el) { return el.ssid; }).indexOf(e.ssid);
             })); // remove duplicates
         };
         registry.valueChanged.connect(wifiImpl.listCallback);
@@ -675,15 +732,7 @@
     })();
 })($);
 
-window.settings.isLuxe = (function () {
-    var w = window,
-        d = document,
-        e = d.documentElement,
-        g = d.getElementsByTagName('body')[0],
-        x = w.innerWidth || e.clientWidth || g.clientWidth,
-        y = w.innerHeight || e.clientHeight || g.clientHeight;
-    return x > 320;
-})();
+window.settings.isLuxe = screen.width > 320;
 
 // session
 (function () {
