@@ -2,16 +2,21 @@
     window.settings = {
         appName: "systemconfig",
 
-        showPage: function (pagePath) {
-            page.showPage("//localhost/cgi-bin/page/show?path=" + window.settings.appName + "/" + pagePath);
+        showPage: function (pagePath, registryValues) {
+            var pageUrl = "//localhost/cgi-bin/page/show?path=" + window.settings.appName + "/" + pagePath;
+            if (registryValues === undefined) {
+                page.showPage(pageUrl);
+            } else {
+                page.showPage(pageUrl, registryValues);
+            }
         },
 
-        is8500: function() {
-            var model = registry.getValue( "platform.terminalModelName" );
+        is8500: function () {
+            var model = registry.getValue("platform.terminalModelName");
             return "LUXE8500i" == model;
         },
 
-        is6200: function() {
+        is6200: function () {
             return !window.settings.is8500();
         }
     };
@@ -25,8 +30,8 @@
         powerImpl = {},
         bleImpl = {},
         flashLightImpl = {},
-        lteImpl = {};
-    logImpl = {};
+        lteImpl = {},
+        logImpl = {};
 
     window.settings.lte = {
         isEnabled: function (callback) {
@@ -264,6 +269,14 @@
             return wifiImpl.isAvailable();
         },
 
+        getWowlanStatus: function () {
+            return wifiImpl.getWowlanStatus();
+        },
+
+        setWowlanStatus: function (args) {
+            return wifiImpl.setWowlanStatus(args);
+        },
+
         getNetworkInterfaces: function (callback) {
             wifiImpl.getNetworkInterfaces(callback);
         },
@@ -275,7 +288,19 @@
         getWifiHeartBeat: function () {
             return wifiImpl.getWifiHeartBeat();
         },
+        getBlackListCleanup: function () {
+            return wifiImpl.getBlackListCleanup();
+        },
+        setBlackListCleanup: function (args) {
+            return wifiImpl.setBlackListCleanup(args);
+        },
+        forgetNetwork: function () {
+            wifiImpl.forgetNetwork();
+        },
 
+        getConfiguredSSID: function () {
+            return wifiImpl.getConfiguredSSID();
+        },
         /**
             {
                 ssid: "",
@@ -406,10 +431,21 @@
             return "1" == registry.getValue("network.wifi.presence");
         };
 
+        wifiImpl.getWowlanStatus = function () {
+            var res = registry.getValue("%network.wifi.phy.wakeup_on_magic");
+            if (res == null) {
+                res = 1;
+            }
+            return res;
+        };
+
+        wifiImpl.setWowlanStatus = function (args) {
+            registry.setValue("%network.wifi.phy.wakeup_on_magic", args);
+        };
+
         wifiImpl.getNetworkInterfaces = function (callback) {
             var xhttp = new XMLHttpRequest();
             xhttp.onreadystatechange = function () {
-                var success = false;
                 try {
                     if (this.readyState != 4 || this.status != 200) {
                         return;
@@ -439,12 +475,35 @@
             registry.setValue("%network.wifi.net.0.heartbeat", args);
         };
 
+        wifiImpl.getBlackListCleanup = function () {
+            return registry.getValue("%network.wifi.net.0.blacklist_cleanup");
+        };
+        wifiImpl.setBlackListCleanup = function (args) {
+            registry.setValue("%network.wifi.net.0.blacklist_cleanup", args);
+        };
+
+        wifiImpl.forgetNetwork = function () {
+            registry.deleteKey('%network.wifi.net.0.*');
+        };
+
+        wifiImpl.getConfiguredSSID = function () {
+            return registry.getValue('%network.wifi.net.0.ssid');
+        };
+
         wifiImpl.setWifiConfig = function (wificonfig) {
             var res;
             var heartbeat = registry.getValue("%network.wifi.net.0.heartbeat");
-            res = registry.deleteKey('%network.wifi.net.0.*') === false;
+            var blacklistcleanup = registry.getValue("%network.wifi.net.0.blacklist_cleanup");
+            res = registry.deleteKey('%network.wifi.net.0.bgscan') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.heartbeat') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.blacklist_cleanup') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.ssid') === false;
+            res |= registry.deleteKey('%network.wifi.net.0.tcp.*') === false;
+
             res |= registry.setValue('%network.wifi.net.0.ssid', wificonfig.ssid) === false;
-            res |= registry.setValue('%network.wifi.net.0.psk', wificonfig.psk) === false;
+            if (wificonfig.psk != null) {
+                res |= registry.setValue('%network.wifi.net.0.psk', wificonfig.psk) === false;
+            }
             res |= registry.setValue('%network.wifi.net.0.tcp.dhcp', wificonfig.dhcp) === false;
 
             if (wificonfig.dhcp === 0) {
@@ -457,6 +516,8 @@
 
             res |= registry.setValue('%network.wifi.net.0.bgscan', 'learn:10:-72:600:/tmp/bgscan.log');
             res |= registry.setValue('%network.wifi.net.0.heartbeat', heartbeat);
+            res |= registry.setValue('%network.wifi.net.0.blacklist_cleanup', blacklistcleanup);
+
             return res;
         };
 
@@ -469,7 +530,7 @@
                     registry.deleteKey('network.wifi.net.connect');
                     var msg = registry.getValue('network.wifi.status');
                     wifiImpl.scanCallback(msg ? "error: " + msg : 'failed to connect (unknown error)');
-                }, 9000);
+                }, 20000);
             registry.subscribe(wifiImpl.stateKey);
             wifiImpl.connect = 1;
             wifiImpl.scanCallback = callback;
@@ -535,19 +596,19 @@
                     var pci = registry.getValue('network.wifi.bss.' + n + '.pci');
                     networks.push({
                         ssid: ssid,
-                        pciCompatible: ( "1" === pci )
+                        pciCompatible: ("1" === pci)
                     });
                 }
                 n++;
             }
 
-            var compare = function(a, b) {
-                if ( a.ssid > b.ssid ) { return 1; }
-                if ( a.ssid < b.ssid ) { return -1; }
+            var compare = function (a, b) {
+                if (a.ssid > b.ssid) { return 1; }
+                if (a.ssid < b.ssid) { return -1; }
                 return 0;
             };
             wifiImpl.callback(networks.sort(compare).filter(function (e, i, a) {
-                return i === a.map(function(el){ return el.ssid; }).indexOf(e.ssid);
+                return i === a.map(function (el) { return el.ssid; }).indexOf(e.ssid);
             })); // remove duplicates
         };
         registry.valueChanged.connect(wifiImpl.listCallback);
@@ -686,27 +747,39 @@
         };
 
         networkImpl.verifyConnection = function (args) {
-            var interfaces = args.iface !== "usb" ? ["eth0", "eth1", "wlan0"] : ["usb0"];
+            var iface = null;
+            switch (args.iface) {
+            case "usb":
+                iface = "usb0";
+                break;
+            case "wlan":
+                iface = "wlan0";
+                break;
+            default:
+                iface = registry.getValue("network.tcp.eth1.mac") ? "eth1" : "eth0";
+                break;
+            }
 
-            for (var i = 0; i < interfaces.length; i++) {
-                if (interfaces[i] !== "wlan0") {
-                    // check for error
-                    var err = registry.getValue("network." + interfaces[i] + ".status");
-                    if (err) {
-                        args.fail(err);
-                        return;
-                    }
-                }
-
-                // check connection status
-                var isRunning = registry.getValue("network." + interfaces[i] + ".tcp.running");
-                if (isRunning === "0") {
-                    args.fail("disconnected");
+            var ipAddr = null;
+            if (iface !== "wlan0") {
+                // check for error
+                var err = registry.getValue("network." + iface + ".status");
+                if (err) {
+                    args.fail(err);
                     return;
                 }
             }
 
-            args.success();
+            // check connection status
+            var isRunning = registry.getValue("network." + iface + ".tcp.running");
+            if (isRunning === "0") {
+                args.fail("disconnected");
+                return;
+            }
+            ipAddr = ipAddr || registry.getValue("network." + iface + ".tcp.ip");
+
+            ipAddr = ipAddr || "Not set";
+            args.success(iface, ipAddr);
         };
 
         networkImpl.enableDHCP = function (args) {
@@ -788,13 +861,21 @@
     // usb impl
     (function () {
         usbImpl.setMode = function (args) {
-            var res = tmcore.usbgadget(args);
-            if (res) {
-                args.fail("USB gadget configuration failed with code " + res);
-                return;
+            if (args.mode == "ethernet") {
+                registry.setValue("%network.usb.net.tcp.mac", args.uniqueMac ? "1" : "0");
+            }
+            if (!args.onlyMacUpdate || args.mode != "ethernet") {
+                setTimeout(function () {
+                    var res = tmcore.usbgadget(args);
+                    if (res) {
+                        args.fail("USB gadget configuration failed with code " + res);
+                        return;
+                    }
+                    args.success(args.mode);
+                }, args.mode == "ethernet" ? 2000 : 0);
+            } else {
+                args.success(args.mode);
             }
-
-            args.success(args.mode);
         };
     })();
 
@@ -870,14 +951,14 @@
         };
 
         powerImpl.setLcdBrightness = function (args) {
-            lcdVal = args.value;
+            var lcdVal = args.value;
             $.get("/cgi-bin/platform/brightness?lcd=" + lcdVal, function (data) {
                 args.status(data.status || -1);
             });
         };
 
         powerImpl.setKeypadBrightness = function (args) {
-            keypadVal = args.value;
+            var keypadVal = args.value;
             $.get("/cgi-bin/platform/brightness?keypad=" + keypadVal, function (data) {
                 args.status(data.status || -1);
             });
@@ -1194,7 +1275,7 @@
         };
         lteImpl.getMessage = function () {
             var rv = registry.getValue("network.lte.message");
-            //registry.deleteKey("network.lte.message");
+            // registry.deleteKey("network.lte.message");
             return rv;
         };
         lteImpl.getPinCounter = function () {
@@ -1264,12 +1345,13 @@
     // Log settings impl
     (function () {
         logImpl.getLogPriority = function (key) {
+            var value;
             try {
-                var value = registry.getValue(key);
+                value = registry.getValue(key);
                 value = parseInt(value);
-                if (isNaN(value)) value = 4;
-                if (value > 7) value = 7;
-                if (value < 0) value = 0;
+                if (isNaN(value)) { value = 4; }
+                if (value > 7) { value = 7; }
+                if (value < 0) { value = 0; }
             } catch (e) {
                 console.log('getLogPriority failed: ' + e.message);
                 value = 4;
@@ -1279,8 +1361,8 @@
 
         logImpl.setLogPriority = function (key, value) {
             try {
-                if (value > 7) value = 7;
-                if (value < 0) value = 0;
+                if (value > 7) { value = 7; }
+                if (value < 0) { value = 0; }
                 registry.setValue(key, value);
             } catch (e) {
                 console.log('setLogPriority failed: ' + e.message);
