@@ -192,7 +192,12 @@ var scrollableArea = {
         var visibleAreaHeight = scrollableAreaEl.clientHeight;
         var offset = undefined;
         if (options.areaType === 'table') {
-            offset = scrollableAreaEl.querySelector("tr:first-child").clientHeight;
+            var scrollableAreaElInstance = scrollableAreaEl.querySelector("tr:first-child");
+            if (scrollableAreaElInstance){
+                offset = scrollableAreaElInstance.clientHeight;                
+            } else {
+                offset = 0;
+            }
         } else {
             var lineHeight = window.getComputedStyle(scrollableAreaEl).getPropertyValue('line-height');
             offset = parseInt(lineHeight.replace('px', ''));
